==> classpath-0.07.tar.gz: classpath-0.07/external/jaxp/source/javax/xml/transform/TransformerConfigurationException.java <==
/*
 * $Id: TransformerConfigurationException.java,v 1.1.1.1 2003/02/01 02:10:27 cbj Exp $
 * Copyright (C) 2001 Andrew Selkirk
 * 
 * This file is part of GNU JAXP, a library.
 *
 * GNU JAXP is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JAXP is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License. 
 */
package javax.xml.transform;

/**
 * TransformerConfigurationException
 * @author	Andrew Selkirk
 * @version	1.0
 */
public class TransformerConfigurationException extends TransformerException {

	//-------------------------------------------------------------
	// Initialization ---------------------------------------------
	//-------------------------------------------------------------

	public TransformerConfigurationException() {
		super((String)null);
	} // TransformerConfigurationException()

	public TransformerConfigurationException(String msg) {
		super(msg);
	} // TransformerConfigurationException()

	public TransformerConfigurationException(Throwable ex) {
		super(ex);
	} // TransformerConfigurationException()

	public TransformerConfigurationException(String msg, Throwable ex) {
		super(msg, ex);
	} // TransformerConfigurationException()


} // TranformerConfigurationException

==> classpath-0.10.tar.gz: classpath-0.10/external/jaxp/source/javax/xml/transform/TransformerConfigurationException.java <==
/*
 * $Id: TransformerConfigurationException.java,v 1.2 2004/05/01 16:18:51 mark Exp $
 * Copyright (C) 2001 Andrew Selkirk
 * 
 * This file is part of GNU JAXP, a library.
 *
 * GNU JAXP is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JAXP is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License. 
 */
package javax.xml.transform;

/**
 * TransformerConfigurationException
 * @author	Andrew Selkirk
 * @version	1.0
 */
public class TransformerConfigurationException extends TransformerException {

  protected SourceLocator locator = null;
  
	//-------------------------------------------------------------
	// Initialization ---------------------------------------------
	//-------------------------------------------------------------

	public TransformerConfigurationException() {
		super((String)null);
	} // TransformerConfigurationException()

	public TransformerConfigurationException(String msg) {
		super(msg);
	} // TransformerConfigurationException()

	public TransformerConfigurationException(Throwable ex) {
		super(ex);
	} // TransformerConfigurationException()

	public TransformerConfigurationException(String msg, Throwable ex) {
		super(msg, ex);
	} // TransformerConfigurationException()

  public TransformerConfigurationException(String msg, SourceLocator locator) {
    super(msg);
    this.locator = locator;
  }

  public TransformerConfigurationException(String msg, SourceLocator locator, Throwable ex) {
    super(msg, ex);
    this.locator = locator;
  }  

} // TranformerConfigurationException
